<?php
class ControllerExtensionPaymentExpapay extends Controller {
	private $error = array();

	public function index() {
		$this->load->language('extension/payment/expapay');

		$this->document->setTitle($this->language->get('heading_title'));

		$this->load->model('setting/setting');

		if (($this->request->server['REQUEST_METHOD'] == 'POST') && $this->validate()) {
			$this->model_setting_setting->editSetting('payment_expapay', $this->request->post);

			$this->session->data['success'] = $this->language->get('text_success');

			$this->response->redirect($this->url->link('marketplace/extension', 'user_token=' . $this->session->data['user_token'] . '&type=payment', true));
		}

		if (isset($this->error['warning'])) {
			$data['error_warning'] = $this->error['warning'];
		} else {
			$data['error_warning'] = '';
		}

		if (isset($this->error['account_id'])) {
			$data['error_account_id'] = $this->error['account_id'];
		} else {
			$data['error_account_id'] = '';
		}

		if (isset($this->error['signing_key'])) {
			$data['error_signing_key'] = $this->error['signing_key'];
		} else {
			$data['error_signing_key'] = '';
		}


		$data['breadcrumbs'] = array();

		$data['breadcrumbs'][] = array(
			'text' => $this->language->get('text_home'),
			'href' => $this->url->link('common/dashboard', 'user_token=' . $this->session->data['user_token'], true)
		);

		$data['breadcrumbs'][] = array(
			'text' => $this->language->get('text_extension'),
			'href' => $this->url->link('marketplace/extension', 'user_token=' . $this->session->data['user_token'] . '&type=payment', true)
		);

		$data['breadcrumbs'][] = array(
			'text' => $this->language->get('heading_title'),
			'href' => $this->url->link('extension/payment/expapay', 'user_token=' . $this->session->data['user_token'], true)
		);

		$data['action'] = $this->url->link('extension/payment/expapay', 'user_token=' . $this->session->data['user_token'], true);

		$data['cancel'] = $this->url->link('marketplace/extension', 'user_token=' . $this->session->data['user_token'] . '&type=payment', true);

		if (isset($this->request->post['payment_expapay_account_id'])) {
			$data['payment_expapay_account_id'] = $this->request->post['payment_expapay_account_id'];
		} else {
			$data['payment_expapay_account_id'] = $this->config->get('payment_expapay_account_id');
		}

		if (isset($this->request->post['payment_expapay_signing_key'])) {
			$data['payment_expapay_signing_key'] = $this->request->post['payment_expapay_signing_key'];
		} else {
			$data['payment_expapay_signing_key'] = $this->config->get('payment_expapay_signing_key');
		}

		if (isset($this->request->post['payment_expapay_total'])) {
			$data['payment_expapay_total'] = $this->request->post['payment_expapay_total'];
		} else {
			$data['payment_expapay_total'] = $this->config->get('payment_expapay_total');
		}

		if (isset($this->request->post['payment_expapay_order_status_id'])) {
			$data['payment_expapay_order_status_id'] = $this->request->post['payment_expapay_order_status_id'];
		} else {
			$data['payment_expapay_order_status_id'] = $this->config->get('payment_expapay_order_status_id');
		}

		$this->load->model('localisation/order_status');

		$data['order_statuses'] = $this->model_localisation_order_status->getOrderStatuses();

		if (isset($this->request->post['payment_expapay_geo_zone_id'])) {
			$data['payment_expapay_geo_zone_id'] = $this->request->post['payment_expapay_geo_zone_id'];
		} else {
			$data['payment_expapay_geo_zone_id'] = $this->config->get('payment_expapay_geo_zone_id');
		}

		$this->load->model('localisation/geo_zone');

		$data['geo_zones'] = $this->model_localisation_geo_zone->getGeoZones();

		if (isset($this->request->post['payment_expapay_status'])) {
			$data['payment_expapay_status'] = $this->request->post['payment_expapay_status'];
		} else {
			$data['payment_expapay_status'] = $this->config->get('payment_expapay_status');
		}


        if (isset($this->request->post['payment_expapay_test'])) {
            $data['payment_expapay_test'] = $this->request->post['payment_expapay_test'];
        } else {
            $data['payment_expapay_test'] = $this->config->get('payment_expapay_test');
        }

		if (isset($this->request->post['payment_expapay_sort_order'])) {
			$data['payment_expapay_sort_order'] = $this->request->post['payment_expapay_sort_order'];
		} else {
			$data['payment_expapay_sort_order'] = $this->config->get('payment_expapay_sort_order');
		}

		$data['header'] = $this->load->controller('common/header');
		$data['column_left'] = $this->load->controller('common/column_left');
		$data['footer'] = $this->load->controller('common/footer');

		$this->response->setOutput($this->load->view('extension/payment/expapay', $data));
	}

	protected function validate() {
		if (!$this->user->hasPermission('modify', 'extension/payment/expapay')) {
			$this->error['warning'] = $this->language->get('error_permission');
		}

		if (!$this->request->post['payment_expapay_account_id']) {
			$this->error['account_id'] = $this->language->get('error_account_id');
		}

		if (!$this->request->post['payment_expapay_signing_key']) {
			$this->error['signing_key'] = $this->language->get('error_signing_key');
		}

		return !$this->error;
	}
}