<?php
class ControllerExtensionPaymentExpapay extends Controller {
    private $expapay_version = "1.0";
    private $expapay_url = "https://gw.expapay.com/v1/purchase";
    private $expapay_test_url = "https://gw.stage.expapay.com/v1/purchase";
	public function index() {

        $this->load->model('checkout/order');

        $order_info = $this->model_checkout_order->getOrder($this->session->data['order_id']);


        //////
        $amount = $this->currency->format($order_info['total'], $order_info['currency_code'], $order_info['currency_value'], false);

        $amount = number_format((float)$amount, 2, '.', '');
        $request_data = array(
            'account_id' => $this->config->get('payment_expapay_account_id'),
            'order_id' => (string)$this->session->data['order_id'],
            'amount' => $amount,
            'payer' =>  array(
                'email' => $order_info['email']
            )
        );

        $request_data['signature'] = $this->__get_signature($request_data);

        $options = array(
            'http' => array(
                'header'  => "Content-type: application/json\r\n",
                'user_agent' => 'Opencart-extension-v' . $this->expapay_version,
                'method'  => 'POST',
                'content' => json_encode($request_data),
                'ignore_errors' => true
            ),
        );


        $context = stream_context_create($options);
        $result = file_get_contents($this->config->get('payment_expapay_test') ? $this->expapay_test_url : $this->expapay_url, false, $context);
        $result = json_decode($result);

        if (array_key_exists('error', $result)) {
            var_dump($result);
        } else {
            $data['redirect_to'] = $result->redirect_to;
        }

		return $this->load->view('extension/payment/expapay', $data);
	}

    private function flatten($array, $prefix="") {
        $result = array();
        foreach($array as $key => $value) {
            if(is_array($value)) $result = $result + $this->flatten($value, "{$prefix}{$key}.");
            else $result[$prefix . $key] = $value;
        }
        return $result;
    }

	public function callback() {
	    if (isset($_REQUEST['error'])) {
            $_REQUEST['error'] = str_replace("'",'"',$_REQUEST['error']);
            $_REQUEST['error'] = json_decode($_REQUEST['error'],true);
        }





        $order_id = $this->session->data['order_id'];

        $signature = $_REQUEST['signature'];
        unset($_REQUEST['route']);
        unset($_REQUEST['signature']);

        if ($this->__get_signature($_REQUEST) != $signature)
            return exit("Invalid signature '$signature' reveived for order id $order_id");



        if (in_array($_REQUEST['status'], array('COMPLETE', 'CAPTURED'))) { //Success
            $this->load->model('checkout/order');
            $this->model_checkout_order->addOrderHistory($this->session->data['order_id'], $this->config->get('payment_expapay_order_status_id'));
            $this->response->redirect($this->url->link('checkout/success'));
        } else {
            $this->response->redirect($this->url->link('checkout/cart'));
        }
    }


    private function __get_signature($request_data) {
        $temp = $this->flatten($request_data);

        ksort($temp);
        return hash_hmac('sha256', join('', $temp), $this->config->get('payment_expapay_signing_key'));
    }
}